]> asedeno.scripts.mit.edu Git - PuTTY.git/blobdiff - ssh.c
Merge reconfig fixes from branch 'pre-0.64'.
[PuTTY.git] / ssh.c
diff --git a/ssh.c b/ssh.c
index 2dc8a081d2f4b94b32db89f05a5802e812f414bb..c2af9e8039661d5e7e278c6f6e35920728ba4682 100644 (file)
--- a/ssh.c
+++ b/ssh.c
@@ -11321,13 +11321,19 @@ static int ssh_return_exitcode(void *handle)
 }
 
 /*
* cfg_info for SSH is the currently running version of the
* protocol. (1 for 1; 2 for 2; 0 for not-decided-yet.)
  */
 static int ssh_cfg_info(void *handle)
 {
     Ssh ssh = (Ssh) handle;
-    return ssh->version;
+    if (ssh->version == 0)
+       return 0; /* don't know yet */
+    else if (ssh->bare_connection)
+       return -1;
+    else
+       return ssh->version;
 }
 
 /*
@@ -11321,13 +11321,19 @@ static int ssh_return_exitcode(void *handle)
 
 /*
- * cfg_info for SSH is the currently running version of the
- * protocol. (1 for 1; 2 for 2; 0 for not-decided-yet.)
+ * cfg_info for SSH is the protocol running in this session.
+ * (1 or 2 for the full SSH-1 or SSH-2 protocol; -1 for the bare
+ * SSH-2 connection protocol, i.e. a downstream; 0 for not-decided-yet.)
  */
 static int ssh_cfg_info(void *handle)